@@ -25,9 +25,9 @@ from .. import (
     ureg,
 )
 
-from .data_tools import vds_writer
+# from ..tools.VDS_tools import vds_writer
 
-NXclass_logger = logging.getLogger("NeXusGenerator.write.NXclass")
+NXclass_logger = logging.getLogger("NeXusGenerator.writer.NXclass")
 
 # NXentry writer
 def write_NXentry(nxsfile: h5py.File, definition: str = "NXmx") -> h5py.Group:
@@ -105,40 +105,34 @@ def write_NXdata(
             ],
         ),
     )
-    # try:
-    #     nxdata = nxsfile.create_group("/entry/data")
-    #     create_attributes(
-    #         nxdata,
-    #         ("NX_class", "axes", "signal", scan_axis + "_indices"),
-    #         (
-    #             "NXdata",
-    #             scan_axis,
-    #             "data",
-    #             [
-    #                 0,
-    #             ],
-    #         ),
-    #     )
-    # except ValueError:
-    #     nxdata = nxsfile["/entry/data"]
 
     # If mode is images, link to blank image data. Else go to events.
     if data_type == "images":
         if len(datafiles) == 1 and write_vds is None:
             nxdata["data"] = h5py.ExternalLink(datafiles[0].name, "data")
         elif len(datafiles) == 1 and write_vds:
-            nxdata[datafiles[0].stem] = h5py.ExternalLink(datafiles[0].name, "data")
-            NXclass_logger.info("Calling VDS writer.")
-            vds_writer(nxsfile, datafiles, write_vds)
+            nxdata["data_000001"] = h5py.ExternalLink(datafiles[0].name, "data")
+            # NXclass_logger.info("Calling VDS writer.")
+            # vds_writer(nxsfile, datafiles, write_vds)
         else:
-            for filename in datafiles:
-                nxdata[filename.stem] = h5py.ExternalLink(filename.name, "data")
-            if write_vds:
-                NXclass_logger.info("Calling VDS writer.")
-                vds_writer(nxsfile, datafiles, write_vds)
+            for n, filename in enumerate(datafiles):
+                tmp_name = f"data_%0{6}d"
+                nxdata[tmp_name % (n + 1)] = h5py.ExternalLink(filename.name, "data")
+            # if write_vds:
+            #     NXclass_logger.info("Calling VDS writer.")
+            #     vds_writer(nxsfile, datafiles, write_vds)
     elif data_type == "events":
-        for filename in datafiles:
-            nxdata[filename.stem] = h5py.ExternalLink(filename.name, "/")
+        # FIXME this needs to consider the fact that the input might simply be a meta file.
+        # Look for meta file to avoid linking to up to 100 files
+        tbr = datafiles[0].stem.split("_")[-1]
+        mf = datafiles[0].stem.replace(tbr, "meta") + datafiles[0].suffix
+        meta = [f for f in datafiles[0].parent.iterdir() if mf in f.as_posix()]
+        # If metafile is not found, link to the data files
+        if len(meta) == 0:
+            for filename in datafiles:
+                nxdata[filename.stem] = h5py.ExternalLink(filename.name, "/")
+        else:
+            nxdata["meta_file"] = h5py.ExternalLink(meta[0].name, "/")
     else:
         sys.exit("Please pass a correct data_type (images or events)")
 
@@ -191,15 +185,6 @@ def write_NXsample(
         ("NX_class",),
         ("NXsample",),
     )
-    # try:
-    #     nxsample = nxsfile.create_group("/entry/sample")
-    #     create_attributes(
-    #         nxsample,
-    #         ("NX_class",),
-    #         ("NXsample",),
-    #     )
-    # except ValueError:
-    #     nxsample = nxsfile["/entry/sample"]
 
     # Create NXtransformations group: /entry/sample/transformations
     nxtransformations = nxsample.require_group("transformations")
@@ -228,6 +213,11 @@ def write_NXsample(
             idx = goniometer["axes"].index(scan_axis)
             try:
                 for k in nxsfile["/entry/data"].keys():
+                    if isinstance(
+                        nxsfile["/entry/data"].get(k, getlink=True), h5py.ExternalLink
+                    ):
+                        # Don't even try to open!
+                        continue
                     if nxsfile["/entry/data"][k].attrs.get("depends_on"):
                         nxsample_ax[ax] = nxsfile[nxsfile["/entry/data"][k].name]
                         nxtransformations[ax] = nxsfile[nxsfile["/entry/data"][k].name]
@@ -386,7 +376,7 @@ def write_NXdetector(
     nxdetector.create_dataset("type", data=np.string_(detector["detector_type"]))
 
     # If there is a meta file, a lot of information will be linked instead of copied
-    if meta:
+    if meta and detector["mode"] == "images":
         for ll in link_list[0]:
             nxdetector[ll] = h5py.ExternalLink(meta.name, detector[ll])
     else:
@@ -478,6 +468,7 @@ def write_NXdetector(
                 detector["depends"][idx],
                 nxtransformations.name + "/two_theta/",
             )
+            dist = detector["starts"][idx]
         else:
             grp_name = ax
             _dep = set_dependency(
@@ -504,6 +495,9 @@ def write_NXdetector(
                 data=set_dependency(ax, path=nxgrp_ax.name),
             )
 
+    # Detector distance
+    nxdetector.create_dataset("distance", data=dist)
+
 
 # NXdetector_module writer
 def write_NXdetector_module(
@@ -649,7 +643,6 @@ def write_NXcollection(
     data_type: Tuple[str, int],
     meta: Path = None,
     link_list: List = None,
-    # nxdetector: h5py.Group, image_size: Union[List, Tuple], data_type: Tuple[str, int]
 ):
     """
     Write a NXcollection group inside NXdetector as detectorSpecific.
@@ -668,7 +661,7 @@ def write_NXcollection(
     grp.create_dataset("y_pixels", data=detector["image_size"][1])
     if data_type[0] == "images":
         grp.create_dataset("nimages", data=data_type[1])
-    if meta:
+    if meta and data_type[0] == "images":
         for l in link_list[1]:
             grp[l] = h5py.ExternalLink(meta.name, detector[l])
     else:
